@@ -10,7 +10,7 @@ vcovPL <- function(x, cluster = NULL, order.by = NULL,
   ## check (and fix) if sandwich is not positive semi-definite
   if(fix && any((eig <- eigen(rval, symmetric = TRUE))$values < 0)) {
     eig$values <- pmax(eig$values, 0)
-    rval <- crossprod(sqrt(eig$values) * t(eig$vectors))
+    rval[] <- crossprod(sqrt(eig$values) * t(eig$vectors))
   }
   return(rval)
 }
